@@ -1,6 +1,6 @@
 startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL, 
-    nrItems = 1, theta = 0, D = 1, randomesque = 1, random.seed=NULL, startSelect = "MFI", 
-    nAvailable = NULL) 
+    nrItems = 1, theta = 0, D = 1, randomesque = 1, random.seed = NULL, 
+    startSelect = "MFI", nAvailable = NULL) 
 {
     if (!is.null(nAvailable)) {
         if (length(nAvailable) != nrow(itemBank)) 
@@ -50,20 +50,19 @@ startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL,
                   items = NULL
                   nr.items <- nrow(itemBank)
                   selected <- rep(0, nr.items)
-if (!is.null(random.seed)) set.seed(random.seed)
+                  if (!is.null(random.seed)) 
+                    set.seed(random.seed)
                   for (i in 1:length(thStart)) {
                     item.dist <- abs(thStart[i] - itemBank[, 
                       2])
                     if (!is.null(nAvailable)) 
                       pos.adm <- (1 - selected) * nAvailable
                     else pos.adm <- 1 - selected
-                    ra <- rank(abs(item.dist - min(item.dist[pos.adm == 
-                      1])))
-                    prov <- which(ra <= randomesque)[pos.adm[ra <= 
-                      randomesque] == 1]
-                    items[i] <- ifelse(length(prov) == 1, prov, 
-                      sample(prov, 1))
-                    selected[items[i]] <- 1
+pr<-sort(item.dist[pos.adm == 1])
+keep<-pr[randomesque]
+prov<-which(pos.adm==1 & item.dist<=keep)
+items[i] <- ifelse(length(prov) == 1, prov, sample(prov, 1))
+selected[items[i]] <- 1
                   }
                 }
                 if (startSelect == "thOpt") {
@@ -78,40 +77,37 @@ if (!is.null(random.seed)) set.seed(random.seed)
                   thMax <- itemBank[, 2] + log((xstar - itemBank[, 
                     3])/(itemBank[, 4] - xstar))/(D * itemBank[, 
                     1])
-if (!is.null(random.seed)) set.seed(random.seed)
+                  if (!is.null(random.seed)) 
+                    set.seed(random.seed)
                   for (i in 1:length(thStart)) {
                     item.dist <- abs(thMax - thStart[i])
                     if (!is.null(nAvailable)) 
                       pos.adm <- (1 - selected) * nAvailable
                     else pos.adm <- 1 - selected
-                    ra <- rank(abs(item.dist - min(item.dist[pos.adm == 
-                      1])))
-                    prov <- which(ra <= randomesque)[pos.adm[ra <= 
-                      randomesque] == 1]
-                    items[i] <- ifelse(length(prov) == 1, prov, 
-                      sample(prov, 1))
-                    selected[items[i]] <- 1
+                    pr<-sort(item.dist[pos.adm == 1])
+keep<-pr[randomesque]
+prov<-which(pos.adm==1 & item.dist<=keep)
+items[i] <- ifelse(length(prov) == 1, prov, sample(prov, 1))
+selected[items[i]] <- 1
                   }
                 }
                 if (startSelect == "MFI") {
                   items = NULL
                   nr.items <- nrow(itemBank)
                   selected <- rep(0, nr.items)
-if (!is.null(random.seed)) set.seed(random.seed)
+                  if (!is.null(random.seed)) 
+                    set.seed(random.seed)
                   for (i in 1:length(thStart)) {
                     item.info <- Ii(thStart[i], itemBank, model = model, 
                       D = D)$Ii
                     if (!is.null(nAvailable)) 
                       pos.adm <- (1 - selected) * nAvailable
                     else pos.adm <- 1 - selected
-                    ra <- rank(abs(item.info - max(item.info[pos.adm == 
-                      1])))
-                    prov <- which(ra <= randomesque)[pos.adm[ra <= 
-                      randomesque] == 1]
-                    items[i] <- ifelse(length(prov) == 1, prov, 
-                      sample(prov, 1))
-                    selected[items[i]] <- 1
-                  }
+pr<-sort(item.info[pos.adm == 1],decreasing=TRUE)
+keep<-pr[randomesque]
+prov<-which(pos.adm==1 & item.info>=keep)
+items[i] <- ifelse(length(prov) == 1, prov, sample(prov, 1))
+selected[items[i]] <- 1                  }
                 }
                 par = itemBank[items, ]
             }
@@ -121,6 +117,6 @@ if (!is.null(random.seed)) set.seed(random.seed)
         else res <- list(items = NULL, par = NULL, thStart = NULL, 
             startSelect = NULL)
     }
-set.seed(NULL)
+    set.seed(NULL)
     return(res)
 }
